{ PVCAM Demonstration Script

  This script captures multiple regions based on ROIs defined 
  in an image using the Region Tool on the toolbar. If the image
  does not have any ROIs defined, the script aborts. A maximum of
  4 image regions are captured.

  NOTE: This script assumes the camera has already been opened
  using either the Camera | Install Cameras menu, or a call to the 
  pvcOpenCamera procedure. }

const
  ChooseMsg = 'Choose an image with at least 4 ROIs' ;
  ErrorMsg  = 'This script requires a desktop image' ;
  AbortMsg  = 'Image does not have any ROIs defined' ;

var
  ROIImage ;   { Image containing the ROIs }
  ImgROI ;     { Array of image ROIs }
  MyROI ;      { PVCAM ROI array }
  Image1 ;     { Captured image #1 }
  Image2 ;     { Captured image #2 }
  Image3 ;     { Captured image #3 }
  Image4 ;     { Captured image #4 }
  
begin

{ Check that a desktop image exists }
if GetNumImages = 0 then Halt( ErrorMsg ) ;

{ Select one of the images }
SelectImage( ChooseMsg,ROIImage ) ;

{ Get the image ROI definitions }
ImgROI := GetROI( ROIImage ) ;

{ Abort if no ROI }
if IsNull( ImgROI ) then Halt( AbortMsg ) ;

{ Create PVCAM ROI array - remember that an ROI defined
  using the Region Tool does not have binning info so we
  need to add 2 extra columns to the PVCAM ROI array }
MyROI := CreateArray( word,6,GetYSize( ImgROI ) ) ;

{ Set binning factor to 1 by filling
  entire array with 1's - quick}
MyROI := 1 ;

{ Fill in region coordinates }
PutRegion( MyROI,ImgROI,0,0 ) ;

{ Set the exposure time, gain and mode }
pvcSetExpTime( 200 ) ;
pvcSetExpMode( pvc_ExpTimed ) ;
pvcSetGain( 1 ) ;

{ Set ROI and capture images
 - only first 4 regions used }
pvcSetROI( MyROI ) ;
pvcCaptureROI( Image1,Image2,Image3,Image4 ) ;

{ Display images }
Show( Image1,'pvdemo04a' ) ;
Show( Image2,'pvdemo04b' ) ;
Show( Image3,'pvdemo04c' ) ;
Show( Image4,'pvdemo04d' ) ;

end
