program  FWLUDL ;
{ LUDL filter wheel control script }
{ By Scott Sternberg, Photometrics Ltd }

{ Below are examples of how to use VPascal with a LUDL filterwheel }
{ The High Level programming mode (ASCII) of the MAC2000 controller is used }
{ Upon excecution, the filterwheel will step through the following functions: }
    { 1. Establish RS-232 communications }
    { 2. Execise the shutter using a vpascal defined exposure time }
    { 3. Home the filterwheel }
    { 4. Step through each filterwheel position }
    { 5. Toggle between two filter positions in fast succession }
    { 6. Exercise the shutter using a LUDL defined exposure time }

const
  del=1000  ;                           {Set Delay Time constant to 1 second}

procedure opser  ;                      {Open Serial Com Port #1}

 begin
  OpenSerial(1,9600,8,Noparity,2) ;     {Open port1}
  Transmit(chr(255)+chr(65)) ;          {Set programming mode to HIGH LEVEL (ASCII)}
 end;                                   {This setting specific to LUDL MAC2000 controller}


procedure clser  ;                      {Close Serial Com Port #1}

 begin
   CloseSerial(1);                      {Close Port1}
 end;

procedure WaitForStop ;                 {Verifys that Filterwheel is finished moving}
 var
   c ;
 begin
   repeat
     Transmit('STATUS S'+chr(13)) ;     {Querys filterwheel as to its status}
      repeat
      until RxWaiting >= 1 ;            {Waits for a change in the input RS-232 buffer}
     c := RxChar ;
   until c <> 'B' ;                     {repeats until a 'B' is not received (not moving)}
 end;

procedure RatioPair;                    {Demonstrates movement for 10 ratio pairs}

 var
   index,tau;
 begin
   tau := 500;                          {Inter-Ratio Pair spacing of 500ms}
   for index := 1 to 10 do
    begin
     Transmit('Open S'+chr(13))  ;
     Transmit('ROTAT S M 5'+chr(13));   {Position #5}
      WaitForStop ;
     Transmit('ROTAT S M 6'+chr(13));   {Position #6}
      WaitForStop ;
     Transmit('Close S'+chr(13))  ;
      Delay (tau);                       
    end ;
 end;


begin
 opser;
                 {****Exercise Shutter****}

  Transmit('Open S'+chr(13))  ;        
   Delay (del);                         {Exposure for <del> seconds}
  Transmit('Close S'+chr(13))  ;
   Delay (30);                          {30 msec delay to let shutter close}
   
                 {****Exercise FilterWheel****}

  Transmit('ROTAT S M H'+chr(13));      {Home Position command plus carraige return}
   WaitForStop ;

  Transmit('Open S'+chr(13))  ;
   Delay (15);                          {15 msec delay to let shutter open}
  Transmit('ROTAT S M 2'+chr(13));      {Position #2}
   Delay (del);
  Transmit('ROTAT S M 3'+chr(13));      {Position #3}
   Delay (del);
  Transmit('ROTAT S M 4'+chr(13));      {Position #4}
   Delay (del);
  Transmit('ROTAT S M 5'+chr(13));      {Position #5}
   Delay (del);
  Transmit('ROTAT S M 6'+chr(13));      {Position #6}
   Delay (del);
  Transmit('Close S'+chr(13));
   Delay (del);
       
  RatioPair;
   Delay (del);
                 {****Exercise Shutter Again using Ludl Timming****}
  
  Transmit('Exp1 S 1000' + chr(13));         {Set exposure time to 1 second}
  Transmit('Exp1 S '+ chr(13));              {Excecute exposure}   
   Delay (del);                              {Wait for exposure to conclude before}
                                             {closing serial port}
                                             
                                             
  clser;                                     {Close Serial Port #1}
  beep ;
   

end.
